// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `cc` vocabulary
//!
//! This module requires `ns-cc` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|cc|
//! |**Namespace base IRI**|<http://creativecommons.org/ns#>|
//! |**Description**||
//! |**Is defined by**|<https://creativecommons.org/schema.rdf>|
//!

use crate::namespace;

namespace!(
    "http://creativecommons.org/ns#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Attribution`: credit be given to 		    copyright holder and/or author
    Attribution, "Attribution",
    /// `Commercial Use`: exercising rights for 		    commercial purposes
    CommercialUse, "CommercialUse",
    /// `Copyleft`: derivative and 		    combined works must be licensed under specified 		    terms, similar to those on the original 		    work
    Copyleft, "Copyleft",
    /// `Derivative Works`: distribution of 		    derivative works
    DerivativeWorks, "DerivativeWorks",
    /// `Distribution`: distribution, public 		    display, and publicly performance
    Distribution, "Distribution",
    /// `High Income Nation Use`: use in a 		    non-developing country
    HighIncomeNationUse, "HighIncomeNationUse",
    /// `Jurisdiction`: the legal jurisdiction 		    of a license
    Jurisdiction, "Jurisdiction",
    /// `Lesser Copyleft`: derivative works must 		    be licensed under specified terms, with at least 		    the same conditions as the original work; 		    combinations with the work may be licensed under 		    different terms
    LesserCopyleft, "LesserCopyleft",
    /// `License`: a set of 		    requests/permissions to users of a Work, e.g. a 		    copyright license, the public domain, information 		    for distributors
    License, "License",
    /// `Notice`: copyright and license 		    notices be kept intact
    Notice, "Notice",
    /// `Permission`: an action that may or 		    may not be allowed or desired
    Permission, "Permission",
    /// `Prohibition`: something you may be 		    asked not to do
    Prohibition, "Prohibition",
    /// `Reproduction`: making multiple 		    copies
    Reproduction, "Reproduction",
    /// `Requirement`: an action that may or 		    may not be requested of you
    Requirement, "Requirement",
    /// `Share Alike`: derivative works be 		    licensed under the same terms or compatible terms 		    as the original work
    ShareAlike, "ShareAlike",
    /// `Sharing`: permits commercial 		    derivatives, but only non-commercial 		    distribution
    Sharing, "Sharing",
    /// `Source Code`: source code (the 		    preferred form for making modifications) must be 		    provided when exercising some rights granted by 		    the license.
    SourceCode, "SourceCode",
    /// `Work`: a potentially 		    copyrightable work
    Work, "Work",
    /// `attributionName`: 
    attributionName, "attributionName",
    /// `attributionURL`: 
    attributionURL, "attributionURL",
    /// `deprecated 		  on`: 
    deprecatedOn, "deprecatedOn",
    /// `jurisdiction`: 
    jurisdiction, "jurisdiction",
    /// `legalcode`: 
    legalcode, "legalcode",
    /// `has 		  license`: 
    license, "license",
    /// `morePermissions`: 
    morePermissions, "morePermissions",
    /// `permits`: 
    permits, "permits",
    /// `prohibits`: 
    prohibits, "prohibits",
    /// `requires`: 
    requires, "requires",
    /// `useGuidelines`: 
    useGuidelines, "useGuidelines"
);
